@@ -70,15 +70,7 @@ sharedptr<SharedConnection> Base_DB::connect_to_server()
 {
   Bakery::BusyCursor(*get_application());
 
-  sharedptr<SharedConnection> result(0);
-
-  ConnectionPool* connection_pool = ConnectionPool::get_instance();
-  if(connection_pool)
-  {
-    result = connection_pool->connect();
-  }
-
-  return result;
+  return ConnectionPool::get_and_connect();
 }
 
 void Base_DB::handle_error(const std::exception& ex) const
@@ -91,37 +83,7 @@ void Base_DB::handle_error(const std::exception& ex) const
 
 bool Base_DB::handle_error() const
 {
-  sharedptr<SharedConnection> sharedconnection = connect_to_server();
-  if(sharedconnection)
-  {
-    Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
-
-    typedef std::list< Glib::RefPtr<Gnome::Gda::Error> > type_list_errors;
-    type_list_errors list_errors = gda_connection->get_errors();
-
-    if(!list_errors.empty())
-    {
-      Glib::ustring error_details;
-      for(type_list_errors::iterator iter = list_errors.begin(); iter != list_errors.end(); ++iter)
-      {
-        if(iter != list_errors.begin())
-          error_details += "\n"; //Add newline after each error.
-
-        error_details += (*iter)->get_description();
-        std::cerr << "Internal error: " << error_details << std::endl;
-      }
-
-      Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
-      dialog.set_secondary_text(error_details);
-      //TODO: dialog.set_transient_for(*get_application());
-      dialog.run();
-
-      return true; //There really was an error.
-    }
-  }
-
-   //There was no error. libgda just did not return any data, and has no concept of an empty datamodel.
-   return false;
+  return ConnectionPool::handle_error();
 }
 
 
@@ -146,7 +108,8 @@ Glib::RefPtr<Gnome::Gda::DataModel> Base_DB::Query_execute(const Glib::ustring&
       std::cout << "Debug: query string could not be converted to std::cout: " << ex.what() << std::endl;
     }
     */
-    
+
+
     result = gda_connection->execute_single_command(strQuery);
     if(!result)
     {
@@ -323,6 +286,9 @@ Base_DB::type_vecFields Base_DB::get_fields_for_table_from_database(const Glib::
 {
   type_vecFields result;
 
+  if(table_name.empty())
+    return result;
+
   // These are documented here:
   // http://www.gnome-db.org/docs/libgda/libgda-provider-class.html#LIBGDA-PROVIDER-GET-SCHEMA
   enum GlomGdaDataModelFieldColumns
@@ -378,8 +344,13 @@ Base_DB::type_vecFields Base_DB::get_fields_for_table_from_database(const Glib::
         //Get the field name:
         Gnome::Gda::Value value_name = data_model_fields->get_value_at(DATAMODEL_FIELDS_COL_NAME, row);
         if(value_name.get_value_type() ==  Gnome::Gda::VALUE_TYPE_STRING)
+        {
+          if(value_name.get_string().empty())
+            g_warning("Base_DB::get_fields_for_table_from_database(): value_name is empty.");
+            
           field_info.set_name( value_name.get_string() );
-
+        }
+        
         //Get the field type:
         //This is a string representation of the type, so we need to discover the Gnome::Gda::ValueType for it:
         Gnome::Gda::Value value_fieldtype = data_model_fields->get_value_at(DATAMODEL_FIELDS_COL_TYPE, row);
@@ -462,7 +433,7 @@ Base_DB::type_vecFields Base_DB::get_fields_for_table(const Glib::ustring& table
     //Look at each field in the database:
     for(type_vecFields::iterator iter = fieldsDocument.begin(); iter != fieldsDocument.end(); ++iter)
     {
-      Glib::ustring field_name = iter->get_name();
+      const Glib::ustring field_name = iter->get_name();
 
       //Get the field info from the database:
       //This is in the document as well, but it _might_ have changed.
@@ -1168,6 +1139,9 @@ void Base_DB::set_database_preferences(const SystemPrefs& prefs)
     {
       std::cerr << "Base_DB::set_database_preferences(): exception: " << ex.what() << std::endl;
     }
+    
+    //Set some information in the document too, so we can use it to recreate the database:
+    get_document()->set_database_title(prefs.m_name);
 }
 
 bool Base_DB::create_table(const TableInfo& table_info, const Document_Glom::type_vecFields& fields) const
@@ -1565,3 +1539,16 @@ void Base_DB::report_build(const Glib::ustring& table_name, const Report& report
 
   GlomUtils::transform_and_open(*pDocument, "print_report_to_html.xsl");
 }
+
+//static
+bool Base_DB::show_warning_no_records_found(Gtk::Window& transient_for)
+{
+  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("No Records Found")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE);
+  dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+  dialog.add_button(_("New Find"), Gtk::RESPONSE_OK);
+  dialog.set_secondary_text(_("Your find criteria did not match any records in the table."));
+  dialog.set_transient_for(transient_for);
+  
+  const bool find_again = (dialog.run() == Gtk::RESPONSE_OK);
+  return find_again;
+}
