@@ -135,7 +135,7 @@ bool Box_Data_List::fill_from_database()
 
     fill_end();
   }
-  catch(std::exception& ex)
+  catch(const std::exception& ex)
   {
     handle_error(ex);
     result = false;
@@ -784,5 +784,15 @@ void Box_Data_List::set_open_button_title(const Glib::ustring& title)
   m_AddDel.set_open_button_title(title);
 }
 
+void Box_Data_List::set_primary_key_value_selected(const Gnome::Gda::Value& primary_key_value)
+{
+  Gtk::TreeModel::iterator iter = m_AddDel.get_row(primary_key_value);
+  if(iter)
+  {
+    m_AddDel.select_item(iter);
+  }
+}
+
+
 
 
