@@ -32,14 +32,23 @@ public:
 
   virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row);
   virtual Gnome::Gda::Value get_primary_key_value_selected();
+  Gnome::Gda::Value get_primary_key_value_first();
 
   virtual Gnome::Gda::Value get_entered_field_data(const LayoutItem_Field& field) const;
   virtual void set_entered_field_data(const LayoutItem_Field& field, const Gnome::Gda::Value& value);
 
   virtual guint get_records_count() const;
 
+  void set_read_only(bool read_only = true);
+
+  //For instance, change "Open" to "Select" when used to select an ID.
+  void set_open_button_title(const Glib::ustring& title);
+
+  ///Highlight and scroll to the specified record, with primary key value @primary_key_value.
+  void set_primary_key_value_selected(const Gnome::Gda::Value& primary_key_value);
+
   //Primary Key value:
-  typedef sigc::signal<void, Gnome::Gda::Value> type_signal_user_requested_details;
+  typedef sigc::signal<void, const Gnome::Gda::Value&> type_signal_user_requested_details;
   type_signal_user_requested_details signal_user_requested_details();
 
   //Signal Handlers:
@@ -47,11 +56,12 @@ public:
   virtual void on_details_nav_previous();
   virtual void on_details_nav_next();
   virtual void on_details_nav_last();
-  virtual void on_Details_record_deleted(Gnome::Gda::Value primary_key_value);
+  virtual void on_Details_record_deleted(const Gnome::Gda::Value& primary_key_value);
 
 protected:
   virtual void create_layout(); //override
   virtual bool fill_from_database(); //override.
+  virtual void enable_buttons();
 
   virtual bool get_field_primary_key_index(guint& field_column) const; //TODO: visible 
   virtual bool get_field_primary_key(Field& field) const;
@@ -82,6 +92,7 @@ protected:
   mutable DbAddDel_WithButtons m_AddDel; //mutable because its get_ methods aren't const.
 
   bool m_has_one_or_more_records;
+  bool m_read_only;
 
   type_signal_user_requested_details m_signal_user_requested_details;
 };
