@@ -30,6 +30,7 @@
 #include "cellrenderer_button.h"
 //#include "../cellrendererlist.h"
 #include <iostream> //For debug output.
+#include <gtk/gtktreeview.h>
 
 DbAddDelColumnInfo::DbAddDelColumnInfo()
 :
@@ -202,7 +203,11 @@ void DbAddDel::setup_menu()
 
   m_refActionGroup->add(Gtk::Action::create("ContextMenu", "Context Menu") );
 
-  m_refContextEdit =  Gtk::Action::create("ContextEdit", Gtk::Stock::EDIT);
+  if(m_open_button_title.empty())
+    m_refContextEdit =  Gtk::Action::create("ContextEdit", Gtk::Stock::EDIT);
+  else
+    m_refContextEdit =  Gtk::Action::create("ContextEdit", m_open_button_title);
+    
   m_refActionGroup->add(m_refContextEdit,
     sigc::mem_fun(*this, &DbAddDel::on_MenuPopup_activate_Edit) );
 
@@ -297,7 +302,9 @@ bool DbAddDel::on_button_press_event_Popup(GdkEventButton *event)
     if(event->type == GDK_2BUTTON_PRESS)
     {
       //Double-click means edit.
-      //Don't do this, because users sometimes double-click by accident when they just want to edit a cell.
+      //Don't do this usually, because users sometimes double-click by accident when they just want to edit a cell.
+      
+      //TODO: If the cell is not editable, handle the double-click as an edit/selection.
       //on_MenuPopup_activate_Edit();
       return false; //Not handled.
     }
@@ -433,6 +440,9 @@ Gtk::TreeModel::iterator DbAddDel::get_item_selected()
 
 Gtk::TreeModel::iterator DbAddDel::get_row(const Gnome::Gda::Value& key)
 {
+  if(!m_refListStore)
+    return Gtk::TreeModel::iterator();
+
   for(Gtk::TreeModel::iterator iter = m_refListStore->children().begin(); iter != m_refListStore->children().end(); ++iter)
   {
     //Gtk::TreeModel::Row row = *iter;
@@ -457,7 +467,7 @@ bool DbAddDel::select_item(const Gtk::TreeModel::iterator& iter, guint column, b
 {
   if(!m_refListStore)
     return false;
-   
+
   InnerIgnore innerIgnore(this); //see comments for InnerIgnore class
 
   bool bResult = false;
@@ -810,7 +820,8 @@ bool DbAddDel::refresh_from_database()
   {
     Glib::RefPtr<Gtk::TreeModel> refNull;
     bool result = m_refListStore->refresh_from_database(m_where_clause);
-    m_TreeView.set_model(refNull); //TODO: Find a better way to indicate that the whole model has changed, because this causes a g_waring().
+    m_TreeView.set_model(refNull); //TODO: This causes a g_waring(): gtk_tree_view_unref_tree_helper: assertion `node != NULL' failed
+    //gtk_tree_view_set_model(m_TreeView.gobj(), 0); //This gives the same warning.
     m_TreeView.set_model(m_refListStore);
     return result;
   }
@@ -986,7 +997,7 @@ void DbAddDel::set_allow_add(bool val)
 
 void DbAddDel::set_allow_delete(bool val)
 {
-  m_allow_delete= val;
+  m_allow_delete = val;
 }
   
   
@@ -1522,7 +1533,6 @@ bool DbAddDel::get_is_last_row(const Gtk::TreeModel::iterator& iter) const
 
 Gtk::TreeModel::iterator DbAddDel::get_next_available_row_with_add_if_necessary()
 {
-g_warning("get_next_available_row_with_add_if_necessary");
   Gtk::TreeModel::iterator result;
 
   if(!m_refListStore)
@@ -1544,7 +1554,7 @@ g_warning("get_next_available_row_with_add_if_necessary");
       }
       else
       {
-        // The last line isn't blank, so we can not use it. Add another one.
+        // The last line isn't blank, so we cannot use it. Add another one.
         result = m_refListStore->append();
       }
     }
@@ -1719,6 +1729,7 @@ void DbAddDel::set_allow_view_details(bool val)
   //Hide it if it was visible:
   if(m_treeviewcolumn_button)
     m_treeviewcolumn_button->property_visible() = get_allow_view_details();
+    
 }
 
 bool DbAddDel::get_allow_view_details() const
@@ -1738,5 +1749,10 @@ void DbAddDel::on_cell_button_clicked(const Gtk::TreeModel::Path& path)
   on_MenuPopup_activate_Edit();
 }
 
+void DbAddDel::set_open_button_title(const Glib::ustring& title)
+{
+  m_open_button_title = title;
+}
+
 
 
