@@ -116,6 +116,8 @@ void FlowTableWithFields::add_layout_item_at_position(const LayoutItem& item, co
 
           //Connect signals:
           portal_box->signal_record_changed().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_portal_record_changed) );
+          
+          portal_box->signal_user_requested_details().connect( sigc::bind( sigc::mem_fun(*this, &FlowTableWithFields::on_portal_user_requested_details), portal_box));
         }
       }
     }
@@ -186,7 +188,9 @@ void FlowTableWithFields::add_layout_group_at_position(const LayoutGroup& group,
 
     //Connect signal:
     flow_table->signal_field_edited().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_entry_edited) );
+    flow_table->signal_field_open_details_requested().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_entry_open_details_requested) );
     flow_table->signal_related_record_changed().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_related_record_changed) );
+    flow_table->signal_requested_related_details().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_requested_related_details) );
   }
 }
 
@@ -287,6 +291,8 @@ void FlowTableWithFields::add_field_at_position(const LayoutItem_Field& layoutit
   info.m_second->signal_edited().connect( sigc::bind(sigc::mem_fun(*this, &FlowTableWithFields::on_entry_edited), layoutitem_field)  ); //TODO:  Is it a good idea to bind the LayoutItem? sigc::bind() probably stores a copy at this point.
   info.m_second->signal_layout_item_added().connect( sigc::bind(
     sigc::mem_fun(*this, &FlowTableWithFields::on_datawidget_layout_item_added), info.m_second) );
+    
+  info.m_second->signal_open_details_requested().connect( sigc::bind(sigc::mem_fun(*this, &FlowTableWithFields::on_entry_open_details_requested), layoutitem_field)  );
 
   m_listFields.push_back(info); //This would be the wrong position, but you should only use this method directly when you expect it to be followed by a complete re-layout.
 }
@@ -354,7 +360,7 @@ Gnome::Gda::Value FlowTableWithFields::get_field_value(const LayoutItem_Field& f
       return datawidget->get_value();
   }
 
-  g_warning("FlowTableWithFields::get_field_value(): returning null");
+  //g_warning("FlowTableWithFields::get_field_value(): returning null");
   return Gnome::Gda::Value(); //null.
 }
 
@@ -536,22 +542,41 @@ FlowTableWithFields::type_signal_field_edited FlowTableWithFields::signal_field_
   return m_signal_field_edited;
 }
 
+FlowTableWithFields::type_signal_field_open_details_requested FlowTableWithFields::signal_field_open_details_requested()
+{
+  return m_signal_field_open_details_requested;
+}
+
 FlowTableWithFields::type_signal_related_record_changed FlowTableWithFields::signal_related_record_changed()
 {
   return m_signal_related_record_changed;
 }
 
+FlowTableWithFields::type_signal_requested_related_details FlowTableWithFields::signal_requested_related_details()
+{
+  return m_signal_requested_related_details;
+}
 
 void FlowTableWithFields::on_entry_edited(const Gnome::Gda::Value& value, LayoutItem_Field field)
 {
   m_signal_field_edited.emit(field, value);
 }
 
+void FlowTableWithFields::on_entry_open_details_requested(const Gnome::Gda::Value& value, LayoutItem_Field field)
+{
+  m_signal_field_open_details_requested.emit(field, value);
+}
+
 void FlowTableWithFields::on_flowtable_entry_edited(const LayoutItem_Field& field, const Gnome::Gda::Value& value)
 {
   m_signal_field_edited.emit(field, value);
 }
 
+void FlowTableWithFields::on_flowtable_entry_open_details_requested(const LayoutItem_Field& field, const Gnome::Gda::Value& value)
+{
+  m_signal_field_open_details_requested.emit(field, value);
+}
+
 void FlowTableWithFields::set_design_mode(bool value)
 {
   FlowTable::set_design_mode(value);
@@ -622,7 +647,10 @@ void FlowTableWithFields::get_layout_group(LayoutGroup& group)
         const LayoutItem* pLayoutItem = (*iter)->get_layout_item();
 
         if(pLayoutItem)
+        {
           group.add_item(*pLayoutItem);
+        }
+          
       }
     }
   }
@@ -643,6 +671,13 @@ void FlowTableWithFields::add_layoutwidgetbase(LayoutWidgetBase* layout_widget,
 
 void FlowTableWithFields::on_layoutwidget_changed()
 {
+  LayoutGroup* pLayoutItem = dynamic_cast<LayoutGroup*>(get_layout_item());
+  if(pLayoutItem)
+  {
+    //Update tha LayoutItem by looking at the child widgets:
+    get_layout_group(*pLayoutItem);
+  }
+
   //Forward the signal to the container:
   signal_layout_changed().emit();
 }
@@ -727,4 +762,13 @@ void FlowTableWithFields::on_flowtable_related_record_changed(const Glib::ustrin
   signal_related_record_changed().emit(relationship_name);
 }
 
+void FlowTableWithFields::on_portal_user_requested_details(Gnome::Gda::Value primary_key_value, Box_Data_List_Related* portal_box)
+{
+  signal_requested_related_details().emit(portal_box->get_relationship().get_to_table(), primary_key_value);
+}
 
+void FlowTableWithFields::on_flowtable_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value)
+{
+  //Forward it to the parent:
+  signal_requested_related_details().emit(table_name, primary_key_value);
+}
