@@ -77,6 +77,54 @@ Glib::ustring GlomUtils::trim_whitespace(const Glib::ustring& text)
   return result;
 }
 
+Glib::ustring GlomUtils::string_replace(const Glib::ustring& src, const Glib::ustring search_for, const Glib::ustring& replace_with)
+{
+  std::string result = src;
+
+  std::string::size_type pos = 0;
+  std::string::size_type len= search_for.size();
+
+  while((pos = result.find(search_for)) != std::string::npos)
+  {
+   result.replace(pos, len, replace_with);
+  }
+
+  return result;
+
+/*
+  //TODO_Performance:
+
+  Glib::ustring result;
+  const size_t src_length = src.size();
+  const size_t search_for_length = search_for.size();
+  //const size_t replace_with_length = replace_with.size();
+
+  size_t src_index = 0;
+  size_t src_index_section_start = 0;
+  while(src_index < src_length)
+  {
+    const bool found = (src.find(search_for.c_str(), src_index) == src_index);
+    if(found)
+    {
+      result += src.substr(src_index_section_start, src_index - src_index_section_start);
+      result += replace_with;
+
+      src_index_section_start = src_index + search_for_length;
+      src_index = src_index_section_start;
+    }
+    else
+      ++src_index;
+  }
+
+  if(src_index_section_start < src_length)
+  {
+    result += src.substr(src_index_section_start);
+  }
+
+  return result;
+*/
+}
+
 
 
 Glib::ustring GlomUtils::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause, const Glib::ustring& sort_clause)
@@ -111,18 +159,22 @@ Glib::ustring GlomUtils::build_sql_select_with_where_clause(const Glib::ustring&
     }
     else
     {
-      Glib::ustring relationship_name = layout_item->get_relationship_name();
+      const Glib::ustring relationship_name = layout_item->get_relationship_name();
       if(!relationship_name.empty())
       {
         const Relationship relationship = layout_item->m_relationship;
 
+        /*
         const Glib::ustring field_table_name = relationship.get_to_table();
         if(field_table_name.empty())
         {
           g_warning("build_sql_select_with_where_clause(): field_table_name is null. relationship name = %s", relationship.get_name().c_str());
         }
+        */
 
-        sql_part_fields += ( field_table_name + "." );
+        //We use relationship_name.field_name instead of related_table_name.field_name,
+        //because, in the JOIN below, will specify the relationship_name as an alias for the related table name
+        sql_part_fields += ( "relationship_" + relationship_name + "." );
 
         //Add the relationship to the list:
         type_list_relationships::const_iterator iterFind = std::find_if(list_relationships.begin(), list_relationships.end(), predicate_FieldHasName<Relationship>( relationship_name ) );
@@ -147,9 +199,10 @@ Glib::ustring GlomUtils::build_sql_select_with_where_clause(const Glib::ustring&
   for(type_list_relationships::const_iterator iter = list_relationships.begin(); iter != list_relationships.end(); ++iter)
   {
     const Relationship& relationship = *iter;
-    sql_part_leftouterjoin += " LEFT OUTER JOIN " + relationship.get_to_table() +
-      " ON (" + relationship.get_from_table() + "." + relationship.get_from_field() + " = " +
-      relationship.get_to_table() + "." + relationship.get_to_field() +
+    sql_part_leftouterjoin += " LEFT OUTER JOIN " + relationship.get_to_table() + 
+      " AS relationship_" + relationship.get_name() + //Specify an alias, to avoid ambiguity when using 2 relationships to the same table.
+      " ON (" + relationship.get_from_table() + "." + relationship.get_from_field() + " = relationship_" +
+      relationship.get_name() + "." + relationship.get_to_field() +
       ")";
   }
 
@@ -158,7 +211,7 @@ Glib::ustring GlomUtils::build_sql_select_with_where_clause(const Glib::ustring&
   if(!where_clause.empty())
     result += " WHERE " + where_clause;
 
- if(!sort_clause.empty())
+  if(!sort_clause.empty())
     result += " ORDER BY " + sort_clause;
 
   return result;
@@ -170,13 +223,13 @@ GlomUtils::type_list_values_with_second GlomUtils::get_choice_values(const Layou
   type_list_values_with_second list_values;
 
   Glib::ustring choice_relationship_name, choice_field, choice_second;
-  field.get_choices(choice_relationship_name, choice_field, choice_second);
+  field.get_formatting_used().get_choices(choice_relationship_name, choice_field, choice_second);
 
-  const Relationship relationship = field.m_choices_related_relationship;
+  const Relationship relationship = field.get_formatting_used().m_choices_related_relationship;
   const Glib::ustring to_table = relationship.get_to_table();
   if(to_table.empty())
   {
-    g_warning("get_choice_values(): table_name is null. relationship name = %s", field.m_choices_related_relationship.get_name().c_str());
+    g_warning("get_choice_values(): table_name is null. relationship name = %s", field.get_formatting_used().m_choices_related_relationship.get_name().c_str());
     return list_values;
   }
 
@@ -194,7 +247,7 @@ GlomUtils::type_list_values_with_second GlomUtils::get_choice_values(const Layou
   sharedptr<SharedConnection> connection = ConnectionPool::get_instance()->connect();
 
 
-  std::cout << "get_choice_values: Executing SQL: " << sql_query << std::endl;
+  //std::cout << "get_choice_values: Executing SQL: " << sql_query << std::endl;
   Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->execute_single_command(sql_query);
 
   if(datamodel)
